@@ -1,4 +1,4 @@
-import autograd.numpy as np
+from surpyval import np
 from scipy.optimize import minimize
 
 
