@@ -1,5 +1,5 @@
 from autograd import jacobian, hessian
-import autograd.numpy as np
+from surpyval import np
 from autograd.numpy.linalg import inv
 
 from scipy.optimize import minimize
@@ -342,6 +342,12 @@ class ParametricFitter():
 
         x, c, n, t = surpyval.xcnt_handler(x=x, c=c, n=n, t=t, tl=tl, tr=tr, xl=xl, xr=xr)
 
+        if (c == 1).all():
+            raise ValueError("Cannot have only right censored data")
+
+        if (c == -1).all():
+            raise ValueError("Cannot have only left censored data")
+
         if surpyval.utils.check_no_censoring(c) and (how == 'MOM'):
             raise ValueError('Method of moments doesn\'t support censoring')
         
@@ -386,33 +392,34 @@ class ParametricFitter():
             fitting_info['fixed_idx'] = fixed_idx
             fitting_info['not_fixed'] = not_fixed
 
-            # Need a better general fitter to include offset
+            # This initial estimation is just terrible
             if init == []:
                 if self.name in ['Gumbel', 'Beta', 'Normal', 'Uniform']:
-                    init = np.array(self._parameter_initialiser(x, c, n))
+                    with np.errstate(all='ignore'):
+                        init = np.array(self._parameter_initialiser(x, c, n))
                 else:
-                    
-                    if x.ndim == 2:
-                        init_mask = np.logical_or(x[:, 0] <= self.support[0],
-                                                  x[:, 0] >= self.support[1])
-                        init_mask = ~np.logical_and(init_mask, c == 0)
-                        xl = x[init_mask, 0]
-                        xr = x[init_mask, 1]
-                        x_init = np.vstack([xl, xr]).T
-                    else:
-                        init_mask = np.logical_or(x <= self.support[0],
-                                                  x >= self.support[1])
-                        init_mask = ~np.logical_and(init_mask, c == 0)
+                    with np.errstate(all='ignore'):
+                        if x.ndim == 2:
+                            init_mask = np.logical_or(x[:, 0] <= self.support[0],
+                                                    x[:, 0] >= self.support[1])
+                            init_mask = ~np.logical_and(init_mask, c == 0)
+                            xl = x[init_mask, 0]
+                            xr = x[init_mask, 1]
+                            x_init = np.vstack([xl, xr]).T
+                        else:
+                            init_mask = np.logical_or(x <= self.support[0],
+                                                    x >= self.support[1])
+                            init_mask = ~np.logical_and(init_mask, c == 0)
 
-                        x_init = x[init_mask]
-                    c_init = c[init_mask]
-                    n_init = n[init_mask]
-                    
+                            x_init = x[init_mask]
+                        c_init = c[init_mask]
+                        n_init = n[init_mask]
+                        
 
-                    init = np.array(self._parameter_initialiser(x_init, c_init, n_init, offset=offset))
-                    
-                    if offset:
-                        init[0] = x.min() - 1.
+                        init = np.array(self._parameter_initialiser(x_init, c_init, n_init, offset=offset))
+                        
+                        if offset:
+                            init[0] = x.min() - 1.
 
                 if lfp:
                     _, _, _, F = nonp.plotting_positions(x, c, n, heuristic='Nelson-Aalen')
@@ -457,7 +464,6 @@ class ParametricFitter():
                     xl=None, xr=None, tl=None, tr=None,
                     **fit_options):
         r"""
-
         The central feature to SurPyval's capability. This function aimed to have an API to mimic the 
         simplicity of the scipy API. That is, to use a simple :code:`fit()` call, with as many or as few
         parameters as is needed.
